# -*- coding: utf-8 -*-
"""
    tqwgp-parser
    ~~~~~~~~~~~~~~~~~~~~~
    TQWGP parser package.

    :copyright: (c) 2021 Yoan Tournade.
"""
import hy
# # Expose main parsing functions.
from .parser import parse_quote, parse_invoices
